@@ -1242,14 +1242,11 @@ def validate_integer(integer, suffix = "El", field = "campo"):
     if pattern.match(unformatted_integer): return None
     return f"No ha ingresado {"un" if suffix == "El" else "una"} {field} {"válido" if suffix == "El" else "válida"}."
 
-def validate_float(number_str, suffix = "El", field = "campo"):
-    if not number_str or not number_str.strip():
-        return f"{suffix} {field} no puede dejarse {"vacío" if suffix == "El" else "vacía"}."
-    try:
-        float(number_str.replace(",", "."))
-        return None
-    except ValueError:
-        return f"No ha ingresado {"un" if suffix == "El" else "una"} {field} {"válido" if suffix == "El" else "válida"}."
+def validate_float(decimal, suffix = "El", field = "campo"):
+    if not decimal or not decimal.strip(): return f"{suffix} {field} no puede dejarse {"vacío" if suffix == "El" else "vacía"}."
+    pattern = re.compile(r"^\d+(\.\d+)?$")
+    if pattern.match(decimal): return None
+    return f"No ha ingresado {"un" if suffix == "El" else "una"} {field} {"válido" if suffix == "El" else "válida"}."
 
 def validate_id(id_str):
     if not id_str or not id_str.strip(): return "El D.N.I. no puede dejarse vacio."
@@ -1309,14 +1306,9 @@ def validate_email(email):
     if email_pattern.match(email): return None
     return "No ha ingresado un correo electrónico válido."
 
-def decimal_format(number, decimal_places = None):
-    if isinstance(number, int):
-        return f"{number:,}".replace(",", "X").replace(".", ",").replace("X", ".")
-    elif isinstance(number, float):
-        if not decimal_places: formatted_str = f"{number:,}"
-        else: formatted_str = f"{number:,.{decimal_places}f}"
-        return formatted_str.replace(",", "X").replace(".", ",").replace("X", ".")
-    return str(number)
+def decimal_format(number):
+    if isinstance(number, float) and number.is_integer(): number = int(number)
+    return f"{number:,}".replace(",", "X").replace(".", ",").replace("X", ".")
 
 def format_id(id_string):
     clean_id = id_string.replace(".", "")
